@@ -27,9 +27,8 @@
 ImportImapSettingSearchPage::ImportImapSettingSearchPage(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *label = new QLabel(i18n("Please select the program from which you like to import IMAP settings:"), this);
     label->setObjectName(QStringLiteral("label"));
     mainLayout->addWidget(label);
@@ -47,7 +46,7 @@ ImportImapSettingSearchPage::~ImportImapSettingSearchPage()
 void ImportImapSettingSearchPage::setProgramList(const QStringList &lst)
 {
     for (const QString &prog : lst) {
-        QListWidgetItem *item = new QListWidgetItem(prog, mFoundProgramList);
+        auto *item = new QListWidgetItem(prog, mFoundProgramList);
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
         item->setCheckState(Qt::Unchecked);
     }
